@@ -24,6 +24,7 @@ or the :doc:`documentation </workflow>` to create files for `echemdb <https://ww
 For the documentation below, the path of a CV is presented simply as a line.
 
 """
+
 # ********************************************************************
 #  This file is part of svgdigitizer.
 #
@@ -151,15 +152,15 @@ class CV(SVGFigure):
         >>> cv.metadata  == \
         ... {'experimental': {'tags': ['BCV', 'HER', 'OER']},
         ...  'source': {'figure': '2b', 'curve': 'solid'},
-        ...  'figure description': {'type': 'digitized',
-        ...                         'simultaneous measurements': ['SXRD', 'SHG'],
-        ...                         'measurement type': 'CV',
-        ...                         'scan rate': {'value': 50.0, 'unit': 'V / s'},
+        ...  'figureDescription': {'type': 'digitized',
+        ...                         'simultaneousMeasurements': ['SXRD', 'SHG'],
+        ...                         'measurementType': 'CV',
+        ...                         'scanRate': {'value': 50.0, 'unit': 'V / s'},
         ...                         'fields': [{'name': 'E','unit': 'mV', 'orientation': 'horizontal', 'reference': 'RHE', 'type': 'number'},
         ...                                    {'name': 'j', 'unit': 'uA / cm2', 'orientation': 'vertical', 'type': 'number'}],
         ...                         'comment': 'noisy data'},
-        ...  'data description': {'type': 'digitized',
-        ...                       'measurement type': 'CV',
+        ...  'dataDescription': {'type': 'digitized',
+        ...                       'measurementType': 'CV',
         ...                       'fields': [{'name': 'E', 'type': 'number', 'unit': 'V', 'reference': 'RHE'},
         ...                                  {'name': 'j', 'type': 'number', 'unit': 'A / m2'},
         ...                                  {'name': 't', 'type': 'number', 'unit': 's'}]}}
