@@ -10,18 +10,23 @@ EXAMPLES::
     Options:
       --help  Show this message and exit.
     Commands:
-      cv        Digitize a cylic voltammogram and create a frictionless...
-      digitize  Digitize a 2D plot.
-      figure    Digitize a figure with units on the axis and create a...
-      paginate  Render PDF pages as individual SVG files with linked PNG images.
-      plot      Display a plot of the data traced in an SVG.
+      create-svg     Write an SVG that shows `png` or `jpeg` as a linked image.
+      cv             Digitize a cylic voltammogram and create a frictionless...
+      digitize       Digitize a 2D plot.
+      figure         Digitize a figure with units on the axis and create a...
+      get-citation   Get the citation from the DOI provided PDF file.
+      get-doi        Get the DOI from the provided PDF file.
+      paginate       Render PDF pages as individual SVG files with linked PNG...
+      plot           Display a plot of the data traced in an SVG.
+      rename-by-key  Rename the provided PDF file by the key derived from...
 
 """
+
 # ********************************************************************
 #  This file is part of svgdigitizer.
 #
 #        Copyright (C) 2021-2023 Albert Engstfeld
-#        Copyright (C)      2021 Johannes Hermann
+#        Copyright (C) 2021-2025 Johannes Hermann
 #        Copyright (C) 2021-2023 Julian Rüth
 #        Copyright (C)      2021 Nicolas Hörmann
 #
@@ -154,7 +159,7 @@ def _create_svgplot(svg, sampling_interval, skewed):
 
 def _create_bibliography(svg, metadata):
     r"""
-    Return a bibtex string built from a BIB file and a key provided in `metadata['source']['citation key']`,
+    Return a bibtex string built from a BIB file and a key provided in `metadata['source']['citationKey']`,
     when both requirements are met. Otherwise an empty string is returned.
 
     This is a helper method for :meth:`_create_outfiles`.
@@ -162,13 +167,11 @@ def _create_bibliography(svg, metadata):
     from pybtex.database import parse_file
 
     metadata.setdefault("source", {})
-    metadata["source"].setdefault("citation key", "")
+    metadata["source"].setdefault("citationKey", "")
 
-    bibkey = metadata["source"]["citation key"]
+    bibkey = metadata["source"]["citationKey"]
     if not bibkey:
-        logger.warning(
-            'No bibliography key found in metadata["source"]["citation key"]'
-        )
+        logger.warning('No bibliography key found in metadata["source"]["citationKey"]')
         return ""
 
     bib_directory = os.path.dirname(svg)
@@ -244,7 +247,7 @@ def digitize(svg, sampling_interval, outdir, skewed):
 @skewed_option
 def digitize_figure(
     svg, sampling_interval, metadata, outdir, bibliography, skewed, si_units
-):
+):  # pylint: disable=too-many-positional-arguments
     """
     Digitize a figure with units on the axis and create a frictionless datapackage.
 
@@ -308,7 +311,7 @@ def digitize_figure(
 @sampling_interval_option
 @outdir_option
 @click.option(
-    "--metadata", type=click.File("rb"), default=None, help="yaml file with metadata"
+    "--metadata", type=click.File("rb"), default=None, help="YAML file with metadata"
 )
 @click.argument("svg", type=click.Path(exists=True))
 @bibliography_option
@@ -316,7 +319,7 @@ def digitize_figure(
 @skewed_option
 def digitize_cv(
     svg, sampling_interval, metadata, outdir, skewed, bibliography, si_units
-):
+):  # pylint: disable=too-many-positional-arguments
     """
     Digitize a cylic voltammogram and create a frictionless datapackage.
 
@@ -450,7 +453,7 @@ def _create_package(metadata, csvname, outdir):
     # Update fields in the datapackage describing the data in the CSV
     package_schema = resource.schema
     data_description_schema = Schema.from_descriptor(
-        {"fields": resource.custom["metadata"]["echemdb"]["data description"]["fields"]}
+        {"fields": resource.custom["metadata"]["echemdb"]["dataDescription"]["fields"]}
     )
 
     new_fields = []
@@ -465,7 +468,7 @@ def _create_package(metadata, csvname, outdir):
         )
 
     resource.schema = Schema.from_descriptor({"fields": new_fields})
-    del resource.custom["metadata"]["echemdb"]["data description"]
+    del resource.custom["metadata"]["echemdb"]["dataDescription"]
 
     return package
 
@@ -500,15 +503,25 @@ def _write_metadata(out, metadata):
     out.write("\n")
 
 
-def _create_linked_svg(svg, png):
+def _create_linked_svg(svg, img, template_file):
     r"""
-    Write an SVG to `svg` that shows `png` as a linked image.
+    Write an SVG to `svg` that shows `image` as a linked image.
 
     This is a helper method for :meth:`paginate`.
     """
+    _create_svg(svg, img, template_file, linked=True)
+
+
+def _create_svg(svg, img, template_file, linked):
+    r"""
+    Write an SVG to `svg` that shows `image` either as a linked or embedded image.
+
+    This is a helper method for :meth:`paginate`.
+    """
+    # pylint: disable=too-many-locals
     from PIL import Image
 
-    width, height = Image.open(png).size
+    width, height = Image.open(img).size
 
     import svgwrite
 
@@ -520,37 +533,225 @@ def _create_linked_svg(svg, png):
 
     from svgwrite.extensions.inkscape import Inkscape
 
-    Inkscape(drawing)
+    inkscape = Inkscape(drawing)
 
-    img = drawing.add(
-        svgwrite.image.Image(
-            png,
-            insert=(0, 0),
-            size=(f"{width}px", f"{height}px"),
+    image_layer = inkscape.layer(id="image-layer", locked=True)
+    # add properties for svgedit
+    image_layer.attribs["class"] = "layer"
+    image_layer.set_desc(title="image-layer")
+    drawing.add(image_layer)
+
+    if linked:
+        image_layer.add(
+            svgwrite.image.Image(
+                img,
+                insert=(0, 0),
+                size=(width, height),
+            )
         )
-    )
+    else:
+        import base64
+        import mimetypes
 
-    # workaround: add missing locking attribute for image element
-    # https://github.com/mozman/svgwrite/blob/c8cbf6f615910b3818ccf939fce0e407c9c789cb/svgwrite/extensions/inkscape.py#L50
-    elements = drawing.validator.elements
-    elements["image"].valid_attributes = {
-        "sodipodi:insensitive",
-    } | elements["image"].valid_attributes
-    img.attribs["sodipodi:insensitive"] = "true"
+        img_mimetype = mimetypes.guess_type(img)[0]
+        with open(img, "rb") as f:
+            encoded = base64.b64encode(f.read()).decode()
+        img_data = f"data:{img_mimetype};base64,{encoded}"
+        image_layer.add(
+            svgwrite.image.Image(
+                href=(img_data),
+                insert=(0, 0),
+                size=(width, height),
+            )
+        )
 
-    drawing.save(pretty=True)
+    digitization_layer = inkscape.layer(id="digitization-layer", locked=False)
+
+    digitization_layer.attribs["class"] = "layer"
+    digitization_layer.set_desc(title="digitization-layer")
+    drawing.add(digitization_layer)
+
+    if template_file:
+        from xml.etree import ElementTree as ET
+
+        template_svg_root = ET.parse(template_file).getroot()
+        main_root = ET.ElementTree(ET.fromstring(drawing.tostring()))
+        layer_id = "digitization-layer"
+        source_layer = template_svg_root.find(
+            f".//{{http://www.w3.org/2000/svg}}g[@id='{layer_id}']"
+        )
+        target_layer = main_root.find(
+            f".//{{http://www.w3.org/2000/svg}}g[@id='{layer_id}']"
+        )
+        if source_layer is not None and target_layer is not None:
+            for elem in source_layer:
+                target_layer.append(elem)
+        main_root.write(svg, xml_declaration=True, encoding="utf-8")
+    else:
+        drawing.save(pretty=True)
 
 
 @click.command()
-@click.option("--onlypng", is_flag=True, help="Only produce png files.")
+@click.argument("pdf")
+def get_doi(pdf):
+    r"""
+    Get the DOI from the provided PDF file.
+
+    EXAMPLES::
+
+    >>> from svgdigitizer.test.cli import invoke, TemporaryData
+    >>> with TemporaryData("**/Hermann_2018_J._Electrochem._Soc._165_J3192.pdf") as directory:
+    ...     invoke(cli, "get-doi", os.path.join(directory, "Hermann_2018_J._Electrochem._Soc._165_J3192.pdf"))
+    10.1149/2.0251815jes
+
+    """
+    from .pdf import Pdf
+
+    print(Pdf(pdf).doi)
+
+
+@click.command()
+@click.argument("pdf")
+def get_citation(pdf):
+    r"""
+    Get the citation from the DOI provided PDF file.
+    """
+    from .pdf import Pdf
+
+    document = Pdf(pdf)
+    citation = document.bibliographic_entry
+
+    if not citation:
+        raise KeyError(f"Failed to get citation from DOI {document.doi}.")
+    print(citation)
+
+
+@click.command()
+@click.argument("pdf")
+def rename_by_key(pdf):
+    r"""
+    Rename the provided PDF file by the key derived from citation.
+
+    """
+    from .pdf import Pdf
+
+    Pdf(pdf).rename_by_key()
+
+
+@click.command()
+@click.option(
+    "--template",
+    type=str,
+    default=None,
+    help="Add builtin template elements in SVG files.",
+)
+@click.option(
+    "--template-file",
+    type=click.Path(dir_okay=False),
+    default=None,
+    help="Add template elements from a custom SVG in the SVG file.",
+)
 @click.option(
     "--outdir",
     type=click.Path(file_okay=False),
     default=None,
     help="Write output files to this directory.",
 )
+@click.argument("img")
+def create_svg(img, template, outdir):
+    r"""
+    Write an SVG that shows `png` or `jpeg` as a linked image.
+
+    """
+    import mimetypes
+
+    mimetype = mimetypes.guess_type(img)[0]
+    if mimetype and mimetype.split("/")[1] in ["jpeg", "png"]:
+        svg = _outfile(img, suffix=".svg", outdir=outdir)
+        _create_svg(svg, img, template, True)
+    else:
+        raise click.BadParameter("Only PNG or JPEG image formats are supported.")
+
+
+def _parse_pages_option(_ctx, _param, value):
+    """
+    Parse page range string and return list of page numbers. Raises if string does not obey the format or start page is higher than stop page.
+        TESTS::
+
+        >>> from svgdigitizer.entrypoint import _parse_pages_option
+        >>> _parse_pages_option(_, _, "1-2")
+        [1, 2]
+
+        >>> _parse_pages_option(_, _, "2-2")
+        [2]
+
+        >>> _parse_pages_option(_, _, "3-2")
+        Traceback (most recent call last):
+        ...
+        click.exceptions.BadParameter: Invalid range. Start must be less than or equal to end.
+
+        >>> _parse_pages_option(_, _, "2 3")
+        Traceback (most recent call last):
+        ...
+        click.exceptions.BadParameter: Invalid format. Use a single number or a range like '3-5'.
+
+    """
+    import re
+
+    if value is None:
+        return None
+
+    match = re.fullmatch(r"(\d+)(?:-(\d+))?", value)
+    if not match:
+        raise click.BadParameter(
+            "Invalid format. Use a single number or a range like '3-5'."
+        )
+
+    start = int(match.group(1))
+    end = int(match.group(2)) if match.group(2) else start
+
+    if start > end:
+        raise click.BadParameter(
+            "Invalid range. Start must be less than or equal to end."
+        )
+
+    return list(range(start, end + 1))
+
+
+@click.command()
+@click.option(
+    "--pages",
+    callback=_parse_pages_option,
+    help="Specify a single page (e.g., '2') or a range (e.g., '3-5').",
+)
+@click.option("--onlypng", is_flag=True, help="Only produce PNG files.")
+@click.option(
+    "--template",
+    type=click.Choice(["basic"]),
+    default=None,
+    help="Add builtin template elements in SVG files.",
+)
+@click.option(
+    "--template-file",
+    type=click.Path(dir_okay=False),
+    default=None,
+    help="Add template elements from a custom SVG in SVG files.",
+)
+@click.option(
+    "--outdir",
+    type=click.Path(file_okay=False),
+    default=None,
+    help="Write output files to this directory.",
+)
+@click.option(
+    "--rename",
+    is_flag=True,
+    help="Specify if files should be named according to the echemdb identifier.",
+)
 @click.argument("pdf")
-def paginate(onlypng, pdf, outdir):
+def paginate(
+    pages, onlypng, rename, template, template_file, pdf, outdir
+):  # pylint: disable=too-many-positional-arguments
     """
     Render PDF pages as individual SVG files with linked PNG images.
 
@@ -564,19 +765,39 @@ def paginate(onlypng, pdf, outdir):
         ...     invoke(cli, "paginate", os.path.join(directory, "mustermann_2021_svgdigitizer_1.pdf"))
 
     """
-    from pdf2image import convert_from_path
+    from importlib.resources import files
 
-    pages = convert_from_path(pdf, dpi=600)
-    pngs = [
-        _outfile(pdf, suffix=f"_p{page}.png", outdir=outdir)
-        for page in range(len(pages))
-    ]
+    from .pdf import Pdf
 
-    for page, png in zip(pages, pngs):
-        page.save(png, "PNG")
+    if template and template_file:
+        raise click.BadParameter(
+            "Please provide either a file or a builtin template name."
+        )
+    if template:
+        template_file = files("svgdigitizer").joinpath(
+            "assets", f"template_{template}.svg"
+        )
 
+    doc = Pdf(pdf)
+
+    if rename:
+        doc.rename_by_key()
+    if not pages:
+        page_range = range(doc.num_pages)
+    else:
+        page_range = pages
+        if page_range not in range(doc.num_pages):
+            raise click.BadParameter(
+                f"Invalid range. Page numbers must be within 0-{doc.num_pages}."
+            )
+    for page_idx in page_range:
+        pix = doc.export_png(page_idx, dpi=600)
+        png = _outfile(doc.filepath, suffix=f"_p{page_idx}.png", outdir=outdir)
+        pix.save(png)
         if not onlypng:
-            _create_linked_svg(_outfile(png, suffix=".svg", outdir=outdir), png)
+            _create_linked_svg(
+                _outfile(png, suffix=".svg", outdir=outdir), png, template_file
+            )
 
 
 cli.add_command(plot)
@@ -584,6 +805,10 @@ cli.add_command(digitize)
 cli.add_command(digitize_figure)
 cli.add_command(digitize_cv)
 cli.add_command(paginate)
+cli.add_command(create_svg)
+cli.add_command(get_doi)
+cli.add_command(get_citation)
+cli.add_command(rename_by_key)
 
 # Register command docstrings for doctesting.
 # Since commands are not functions anymore due to their decorator, their
